==> elucidata-build-tools-1.0.1.tgz: package/lib/elucidata-build-tools/index.js <==
(function() {
  var builder, fs, inspect, options, puts, say, server, set_options, _, _ref;
  var __slice = Array.prototype.slice;
  _ref = require('sys'), puts = _ref.puts, inspect = _ref.inspect;
  _ = require('underscore')._;
  fs = require('fs');
  builder = require('./builder');
  server = require('./server');
  options = {
    quiet: false,
    compress: false
  };
  say = function(msg) {
    if (!options.quiet) {
      return puts(msg);
    }
  };
  set_options = function(opts) {
    options = _.extend(options, opts);
    builder.setOptions(opts);
    return server.setOptions(opts);
  };
  _.extend(exports, {
    say: say,
    setOptions: function(opts) {
      return set_options(opts);
    },
    buildJs: function() {
      var opts, output, paths, _i;
      output = arguments[0], paths = 3 <= arguments.length ? __slice.call(arguments, 1, _i = arguments.length - 1) : (_i = 1, []), opts = arguments[_i++];
      set_options(opts);
      return builder.js(paths, function(err, js) {
        if (err) {
          return say("!!! " + err);
        } else {
          fs.writeFileSync(output, js);
          return say(" - " + output);
        }
      });
    },
    buildCss: function(output, path, opts) {
      set_options(opts);
      return builder.css(path, function(err, css) {
        if (err) {
          return say("!!! " + err);
        } else {
          fs.writeFileSync(output, css);
          return say(" - " + output);
        }
      });
    },
    test: function(opts) {
      set_options(opts);
      return say('Testing? Uh... sure');
    },
    serve: function(jsPaths, cssPath, opts) {
      server = require("./server");
      say("Serving at http://127.0.0.1:3000");
      return server.listen(jsPaths, cssPath, opts);
    },
    builder: builder,
    server: server
  });
}).call(this);

==> elucidata-build-tools-1.0.3.tgz: package/lib/elucidata-build-tools/index.js <==
(function() {
  var builder, fs, inspect, options, puts, say, server, set_options, _, _ref;
  var __slice = Array.prototype.slice;
  _ref = require('sys'), puts = _ref.puts, inspect = _ref.inspect;
  _ = require('underscore')._;
  fs = require('fs');
  builder = require('./builder');
  server = require('./server');
  options = {
    quiet: false,
    compress: false
  };
  say = function(msg) {
    if (!options.quiet) {
      return puts(msg);
    }
  };
  set_options = function(opts) {
    options = _.extend(options, opts);
    builder.setOptions(opts);
    return server.setOptions(opts);
  };
  _.extend(exports, {
    say: say,
    builder: builder,
    server: server,
    setOptions: function(opts) {
      return set_options(opts);
    },
    buildJs: function() {
      var opts, output, paths, _i;
      output = arguments[0], paths = 3 <= arguments.length ? __slice.call(arguments, 1, _i = arguments.length - 1) : (_i = 1, []), opts = arguments[_i++];
      set_options(opts);
      return builder.js(paths, opts, function(err, js) {
        if (err) {
          return say("!!! " + (err.message || err));
        } else {
          fs.writeFileSync(output, js);
          return say(" - " + output);
        }
      });
    },
    buildCss: function(output, path, opts) {
      set_options(opts);
      return builder.css(path, opts, function(err, css) {
        if (err) {
          return say("!!! " + (err.message || err));
        } else {
          fs.writeFileSync(output, css);
          return say(" - " + output);
        }
      });
    },
    test: function(opts) {
      var reporters;
      set_options(opts);
      invoke('build');
      process.chdir(__dirname);
      reporters = require('nodeunit').reporters;
      return reporters["default"].run(['test']);
    }
  });
}).call(this);
